Simple test
------------

Ensure your device works with this simple test that prints out the time from NTP.

.. literalinclude:: ../examples/ntp_simpletest.py
    :caption: examples/ntp_simpletest.py
    :linenos:

Set RTC
------------

Sync your CircuitPython board's realtime clock (RTC) with time from NTP.

.. literalinclude:: ../examples/ntp_set_rtc.py
    :caption: examples/ntp_set_rtc.py
    :linenos:

Simple test with CPython
------------------------

Test the library in CPython using ``socket``.

.. literalinclude:: ../examples/ntp_cpython.py
    :caption: examples/ntp_cpython.py
    :linenos:
